[LON-CAPA-cvs] cvs: loncom /automation batchcreatecourse.pm /html/adm/help/tex Batch_Creation.tex /interface loncommon.pm loncoursequeueadmin.pm loncreatecourse.pm

raeburn raeburn at source.lon-capa.org
Thu Aug 25 18:33:10 EDT 2016


raeburn		Thu Aug 25 22:33:10 2016 EDT

  Modified files:              
    /loncom/interface	loncommon.pm loncoursequeueadmin.pm 
                     	loncreatecourse.pm 
    /loncom/automation	batchcreatecourse.pm 
    /loncom/html/adm/help/tex	Batch_Creation.tex 
  Log:
  - Courses created by process a course request will have comment.email set
    to username:domain of requester.
  - XML file used for batch course creation can also include <setcomment> tag
    which when set to 1 will have the same result.
  
  
Index: loncom/interface/loncommon.pm
diff -u loncom/interface/loncommon.pm:1.1250 loncom/interface/loncommon.pm:1.1251
--- loncom/interface/loncommon.pm:1.1250	Mon Jul 18 19:28:58 2016
+++ loncom/interface/loncommon.pm	Thu Aug 25 22:33:02 2016
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common routines
 #
-# $Id: loncommon.pm,v 1.1250 2016/07/18 19:28:58 raeburn Exp $
+# $Id: loncommon.pm,v 1.1251 2016/08/25 22:33:02 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -15501,6 +15501,9 @@
        if ($args->{'setcontent'}) {
            $cenv{'question.email'}=$args->{'ccuname'}.':'.$args->{'ccdomain'};
        }
+       if ($args->{'setcomment'}) {
+           $cenv{'comment.email'}=$args->{'ccuname'}.':'.$args->{'ccdomain'};
+       }
     }
     if ($args->{'reshome'}) {
 	$cenv{'reshome'}=$args->{'reshome'}.'/';
Index: loncom/interface/loncoursequeueadmin.pm
diff -u loncom/interface/loncoursequeueadmin.pm:1.54 loncom/interface/loncoursequeueadmin.pm:1.55
--- loncom/interface/loncoursequeueadmin.pm:1.54	Sun Jun 19 00:19:31 2016
+++ loncom/interface/loncoursequeueadmin.pm	Thu Aug 25 22:33:03 2016
@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Utilities to administer domain course requests and course self-enroll requests
 #
-# $Id: loncoursequeueadmin.pm,v 1.54 2016/06/19 00:19:31 raeburn Exp $
+# $Id: loncoursequeueadmin.pm,v 1.55 2016/08/25 22:33:03 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1706,6 +1706,7 @@
         $batchhash{'users'}{$owner}{lastname} = $owner_lastname;
         $batchhash{'users'}{$owner}{emailenc} = $emailenc;
         $batchhash{'users'}{$owner}{owneremail} = $owneremail;
+        $batchhash{'setcomment'} = 1;
     }
     return %batchhash;
 }
Index: loncom/interface/loncreatecourse.pm
diff -u loncom/interface/loncreatecourse.pm:1.162 loncom/interface/loncreatecourse.pm:1.163
--- loncom/interface/loncreatecourse.pm:1.162	Fri Apr 15 19:27:37 2016
+++ loncom/interface/loncreatecourse.pm	Thu Aug 25 22:33:03 2016
@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Create a course
 #
-# $Id: loncreatecourse.pm,v 1.162 2016/04/15 19:27:37 raeburn Exp $
+# $Id: loncreatecourse.pm,v 1.163 2016/08/25 22:33:03 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -189,7 +189,8 @@
                     'oaas' => "Open all assessments",
                     'mssg' => "Messaging",
                     'scpf' => "Set course policy feedback to Course Coordinator",
-                    'scfc' => "Set content feedback to Course Coordinator",
+                    'scfc' => "Set resource content feedback to Course Coordinator",
+                    'scof' => "Set course content feedback to Course Coordinator",
                     'cmmn' => "Communication",
                     'dsrd' => "Disable student resource discussion",
                     'dsuc' => "Disable student use of chat rooms",
@@ -236,7 +237,8 @@
         $lt{'navi'} = &mt('Community Contents');
         $lt{'cid'}  = &mt('Community ID');
         $lt{'scpf'} = &mt('Set community policy feedback to Coordinator');
-        $lt{'scfc'} = &mt('Set content feedback to Coordinator');
+        $lt{'scfc'} = &mt('Set resource content feedback to Coordinator');
+        $lt{'scof'} = &mt('Set community content feedback to Coordinator');
         $lt{'dsrd'} = &mt('Disable member resource discussion');
         $lt{'dsuc'} = &mt('Disable member use of chat rooms');
         $lt{'dads'} = &mt('Default Access Dates for Members');
@@ -484,6 +486,10 @@
                  .'<input type="checkbox" name="setcontent" checked="checked" />'
                  .&Apache::lonhtmlcommon::row_closure()
 
+                 .&Apache::lonhtmlcommon::row_title($lt{'scof'})
+                 .'<input type="checkbox" name="setcomment" checked="checked" />'
+                 .&Apache::lonhtmlcommon::row_closure()
+
                  .&Apache::lonhtmlcommon::row_headline()
                  .'<h3>'.$lt{'cmmn'}.'</h3>'
                  .&Apache::lonhtmlcommon::row_closure()
@@ -680,6 +686,7 @@
                endaccess => $endaccess,
                setpolicy => $env{'form.setpolicy'},
                setcontent => $env{'form.setcontent'},
+               setcomment => $env{'form.setcomment'},
                reshome => $env{'form.reshome'},
                setkeys => $env{'form.setkeys'},
                keyauth => $env{'form.keyauth'},
Index: loncom/html/adm/help/tex/Batch_Creation.tex
diff -u loncom/html/adm/help/tex/Batch_Creation.tex:1.6 loncom/html/adm/help/tex/Batch_Creation.tex:1.7
--- loncom/html/adm/help/tex/Batch_Creation.tex:1.6	Thu Aug 18 13:50:30 2016
+++ loncom/html/adm/help/tex/Batch_Creation.tex	Thu Aug 25 22:33:10 2016
@@ -39,6 +39,7 @@
 <showphotos></showphotos>
 <setpolicy>1</setpolicy>
 <setcontent>1</setcontent>
+<setcomment>1</setcomment>
 <setkeys>0</setkeys>
 <keyauth>keyadmin at msu</keyauth>
 <disresdis>1</disresdis>




More information about the LON-CAPA-cvs mailing list
Index: loncom/automation/batchcreatecourse.pm
diff -u loncom/automation/batchcreatecourse.pm:1.41 loncom/automation/batchcreatecourse.pm:1.42
--- loncom/automation/batchcreatecourse.pm:1.41	Sat Apr  2 04:30:47 2016
+++ loncom/automation/batchcreatecourse.pm	Thu Aug 25 22:33:06 2016
@@ -1,5 +1,5 @@
 #
-# $Id: batchcreatecourse.pm,v 1.41 2016/04/02 04:30:47 raeburn Exp $
+# $Id: batchcreatecourse.pm,v 1.42 2016/08/25 22:33:06 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -83,6 +83,7 @@
 # <showphotos></showphotos>
 # <setpolicy>1</setpolicy>
 # <setcontent>1</setcontent>
+# <setcomment>1</setcomment>
 # <setkeys>0</setkeys>
 # <keyauth>keyadmin:msu</keyauth>
 # <disresdis>1</disresdis>
@@ -152,7 +153,7 @@
 #
 # Many of these are binary options (corresponding to either checkboxes or
 # radio buttons in the interactive CCRS page).  Examples include:
 # setpolicy, setcontent, setkeys, disableresdis, disablechat, openall,
 # uniquecode
 #
 # A value of 1 between opening and closing tags is equivalent to a 
@@ -266,7 +267,7 @@
     my $xlist = 0;
     my $userkey = '';
     my $role = '';
-    my @items = ('title','optional_id','coursecode','defaultcredits','coursehome','reshome','nonstandard','adds','drops','topmap','firstres','clonecrs','clonedom','datemode','dateshift','showphotos','setpolicy','setcontent','setkeys','keyauth','disresdis','disablechat','openall','notify_owner','notify_dc','crstype','crsquota','uniquecode');
+    my @items = ('title','optional_id','coursecode','defaultcredits','coursehome','reshome','nonstandard','adds','drops','topmap','firstres','clonecrs','clonedom','datemode','dateshift','showphotos','setpolicy','setcontent','setcomment','setkeys','keyauth','disresdis','disablechat','openall','notify_owner','notify_dc','crstype','crsquota','uniquecode');
     my @possroles = qw(st ad ep ta in cc co);
     my @dateitems = ('enrollstart','enrollend','accessstart','accessend');
     my @useritems = ('autharg','authtype','firstname','generation','lastname','middlename','studentID');
@@ -540,6 +541,7 @@
                endaccess => $details->{'accessend'},
                setpolicy => $details->{'setpolicy'},
                setcontent => $details->{'setcontent'},
+               setcomment => $details->{'setcomment'},
                reshome => $reshome,
                setkeys => $details->{'setkeys'},
                keyauth => $details->{'keyauth'},
@@ -152,7 +153,7 @@
 # Many of these are binary options (corresponding to either checkboxes or
 # radio buttons in the interactive CCRS page).  Examples include:
-# setpolicy, setcontent, setkeys, disableresdis, disablechat, openall,
+# setpolicy, setcontent, setcomment, setkeys, disableresdis, disablechat, openall,
 # uniquecode
 #